Changelog for `iadpython` package
=================================

v0.5.0
------
* inverse calculation works for 0 spheres
* much more testing
* basic multiple layers support
* single location for version number
* revert to sphinx_rtd_theme

v0.4.0
------
* forward adding-doubling calculation is pure python now
* create pure python packages
* include wheel file
* package as python3 only
* use sphinx_book_theme for docs

v0.3.0
------
* improve packaging
* improve documentation with Sphinx
* use tox
* add better diagnostics for finding libiad library

v0.2.5
------
* add doc files to distribution
* promise only python 3 and non-zip
* improve long description

v0.2.4
* fix bugs found by C Regan
* (unreleased??)

v0.2.3
------
* fix __init__.py so "import iadpython" works

v0.2.2
------
* necessary because setup.py version did not get updated

v0.2.1
------
* remove ctypes as a requirement

v0.2.0
------
* initial checkin
* Convert to markdown format
* update to correct contents
* add ctypes as dependancy, fix test path
* update my notes on how to cut a release
